@@ -190,15 +190,14 @@ void MainWindow::askForPermissions()
     PolkitQt1::Authority *authority = PolkitQt1::Authority::instance();
 
     PolkitQt1::Authority::Result result;
-    QEventLoop e;
-    connect(authority, &PolkitQt1::Authority::checkAuthorizationFinished, &e,
-            [&e, &result](PolkitQt1::Authority::Result _result) {
+    connect(authority, &PolkitQt1::Authority::checkAuthorizationFinished, &m_AuthorizationEventLoop,
+            [this, &result](PolkitQt1::Authority::Result _result) {
                 result = _result;
-                e.quit();
+                m_AuthorizationEventLoop.quit();
             });
 
     authority->checkAuthorization(QStringLiteral("org.kde.kpmcore.externalcommand.init"), subject, PolkitQt1::Authority::AllowUserInteraction);
-    e.exec();
+    m_AuthorizationEventLoop.exec();
 
     if (authority->hasError()) {
         qDebug() << "Encountered error while checking authorization, error code:"
@@ -224,6 +223,8 @@ QMenu *MainWindow::createPopupMenu()
 
 void MainWindow::closeEvent(QCloseEvent* event)
 {
+    if (m_AuthorizationEventLoop.isRunning())
+        m_AuthorizationEventLoop.quit();
     if (applyProgressDialog().isVisible()) {
         event->ignore();
         return;
@@ -1081,7 +1082,7 @@ void MainWindow::onImportPartitionTable()
         QRegularExpressionMatch rePartition = re.match(line);
         re.setPattern(QStringLiteral("type:\\s\"(.+)\""));
         QRegularExpressionMatch reType = re.match(line);
-        re.setPattern(QStringLiteral("align:\\s\"(cylinder|sector)\""));
+        re.setPattern(QStringLiteral("align:\\s\"(sector)\""));
         QRegularExpressionMatch reAlign = re.match(line);
         re.setPattern(QStringLiteral("^##|v(\\d+)|##"));
         QRegularExpressionMatch reMagic = re.match(line);
@@ -1190,9 +1191,6 @@ void MainWindow::onImportPartitionTable()
         } else
             Log(Log::Level::warning) << xi18nc("@info:status", "Could not parse line %1 from import file. Ignoring it.", lineNo);
     }
-
-    if (ptable->type() == PartitionTable::msdos && ptable->isSectorBased(device))
-        ptable->setType(device, PartitionTable::msdos_sectorbased);
 }
 
 void MainWindow::onExportPartitionTable()
@@ -1351,11 +1349,6 @@ void MainWindow::onPropertiesDevice(const QString&)
 
         QPointer<DevicePropsDialog> dlg = new DevicePropsDialog(this, d);
         if (dlg->exec() == QDialog::Accepted) {
-            if (d.partitionTable()->type() == PartitionTable::msdos && dlg->sectorBasedAlignment())
-                d.partitionTable()->setType(d, PartitionTable::msdos_sectorbased);
-            else if (d.partitionTable()->type() == PartitionTable::msdos_sectorbased && dlg->cylinderBasedAlignment())
-                d.partitionTable()->setType(d, PartitionTable::msdos);
-
             on_m_OperationStack_devicesChanged();
             pmWidget().updatePartitions();
         }
